@@ -36,6 +36,7 @@ typedef struct csch_conn_s {
 	csch_chdr_t hdr;
 	vtp0_t conn;                /* (csch_chdr_t *); xorcache: if not empty, ->conn_path is empty */
 	csch_oid_t gfx;
+	unsigned dirty:1;           /* mark connections that need to be updated */
 
 	/* cache: file I/O version */
 	csch_vtoidpath_t conn_path; /* xorcache: if not empty, ->conn is empty */
@@ -77,9 +78,15 @@ void csch_conn_auto_recalc(csch_sheet_t *sheet, csch_chdr_t *obj);
 void csch_conn_auto_recalc_geo(csch_sheet_t *sheet, csch_chdr_t *obj);
 
 
-/* Convert conn's textual path field into object pointers */
+/* Convert conn's oid-path field into object pointers */
 void csch_conn_text2ptr(csch_sheet_t *sheet, csch_conn_t *conn);
 
+/* Convert conn's object pointers into the oid-path field; useful if some an
+   object is recreated (changing pointer), which would make the object's
+   old dangling pointer remain in the pointer vector */
+void csch_conn_ptr2text(csch_sheet_t *sheet, csch_conn_t *conn);
+
+
 /* Return an existing connection if owner's (maybe currently removed) conn
    could be merged into it. Useful when owner is moved from one group to
    another: its connections need to be moved but if there are existing conn
@@ -87,4 +94,7 @@ void csch_conn_text2ptr(csch_sheet_t *sheet, csch_conn_t *conn);
    reused/extended. */
 csch_conn_t *csch_conn_find_mergable(csch_sheet_t *sheet, csch_conn_t *conn, csch_chdr_t *owner);
 
+/* Update all connections that are marked dirty, recursively */
+void csch_conn_update_dirties(csch_sheet_t *sheet, csch_cgrp_t *grp, int do_xform);
+
 #endif
