@@ -67,8 +67,15 @@ void csch_cgrp_modify_uuid(csch_sheet_t *sheet, csch_cgrp_t *grp, minuid_bin_t *
 
 
 /*** non-standard calls on group refs ***/
-void csch_cgrp_ref_clean(csch_sheet_t *sheet, csch_cgrp_t *grpref); /* remove all objects */
-void csch_cgrp_ref_render(csch_sheet_t *sheet, csch_cgrp_t *grpref); /* copy objects from the referenced group */
+
+/* remove all objects from the ref; NOTE: this converts some conns from
+   object pointers back to object path list. The caller needs to update
+   dirty conns. */
+void csch_cgrp_ref_clean(csch_sheet_t *sheet, csch_cgrp_t *grpref);
+
+/* copy objects from the referenced group; may call csch_cgrp_ref_clean(),
+   thus may need conn dirty recalc, see csch_cgrp_ref_clean() */
+void csch_cgrp_ref_render(csch_sheet_t *sheet, csch_cgrp_t *grpref);
 
 /* Return an attribute by key, before the merge, considering both grpref and the referenced group */
 csch_attrib_t *csch_cgrp_ref_get_attr(csch_cgrp_t *grpref, const char *key);
@@ -76,12 +83,6 @@ csch_attrib_t *csch_cgrp_ref_get_attr(csch_cgrp_t *grpref, const char *key);
 /* Convert a group ref into a group in-place */
 void csch_grp_ref_embed(csch_cgrp_t *grpref);
 
-/*** non-standard calls on groups ***/
-void csch_cgrp_insert_(csch_cgrp_t *grp, csch_chdr_t *hdr);
-void csch_cgrp_insert(csch_cgrp_t *grp, csch_oid_t oid);
-void csch_cgrp_remove_(csch_cgrp_t *grp, csch_chdr_t *hdr);
-void csch_cgrp_remove(csch_cgrp_t *grp, csch_oid_t oid);
-
 /* Calculate cgrp's inverse transformation matrix in dst; useful for
    determining how a sheet coord system oepration translates into a
    group's coord system, e.g. when moving floaters */
