@@ -57,14 +57,14 @@ void csch_child_xform_modify(csch_sheet_t *sheet, csch_cgrp_t *grpref, long idx,
 
 
 
-csch_inline csch_child_xform_t *csch_grp_ref_get_child_xform(csch_cgrp_t *grp, long idx)
+RND_INLINE csch_child_xform_t *csch_grp_ref_get_child_xform(csch_cgrp_t *grp, long idx)
 {
 	if (grp->hdr.type != CSCH_CTYPE_GRP_REF) return NULL;
 	if ((idx < 0) || (idx >= grp->data.ref.child_xform.used)) return NULL;
 	return grp->data.ref.child_xform.array[idx];
 }
 
-csch_inline g2d_xform_t csch_grp_ref_parent_mx(csch_chdr_t *obj, csch_child_xform_t **cx_out)
+RND_INLINE g2d_xform_t csch_grp_ref_parent_mx(csch_chdr_t *obj, csch_child_xform_t **cx_out)
 {
 	g2d_xform_t mx;
 	csch_child_xform_t *cx;
@@ -96,7 +96,7 @@ csch_inline g2d_xform_t csch_grp_ref_parent_mx(csch_chdr_t *obj, csch_child_xfor
 	return mx;
 }
 
-csch_inline int csch_grp_ref_child_xform_is_empty(csch_child_xform_t *cx)
+RND_INLINE int csch_grp_ref_child_xform_is_empty(csch_child_xform_t *cx)
 {
 	if (cx->movex != 0) return 0;
 	if (cx->movey != 0) return 0;
@@ -110,7 +110,7 @@ csch_inline int csch_grp_ref_child_xform_is_empty(csch_child_xform_t *cx)
 
 /* find the topmost group reference above obj (or return NULL if no group ref
    is found in the ancestry) */
-csch_inline csch_cgrp_t *csch_grp_ref_get_top(csch_sheet_t *sheet, csch_chdr_t *obj)
+RND_INLINE csch_cgrp_t *csch_grp_ref_get_top(csch_sheet_t *sheet, csch_chdr_t *obj)
 {
 	csch_cgrp_t *g, *last = NULL;
 
@@ -126,7 +126,7 @@ csch_inline csch_cgrp_t *csch_grp_ref_get_top(csch_sheet_t *sheet, csch_chdr_t *
 }
 
 
-csch_inline csch_child_xform_t *csch_grp_ref_child_get_cx(csch_cgrp_t *grpref, csch_chdr_t *obj, long *idx_out)
+RND_INLINE csch_child_xform_t *csch_grp_ref_child_get_cx(csch_cgrp_t *grpref, csch_chdr_t *obj, long *idx_out)
 {
 	csch_oidpath_t path = {0};
 	csch_cgrp_t *g;
@@ -170,7 +170,7 @@ csch_inline csch_child_xform_t *csch_grp_ref_child_get_cx(csch_cgrp_t *grpref, c
 #define CSCH_PREPARE_GRPREF \
 	csch_cgrp_t *grpref = obj->grp_ref_xform.g; \
 	long idx = obj->grp_ref_xform.idx; \
-		csch_child_xform_t *cx; \
+	csch_child_xform_t *cx; \
 	if (grpref == NULL) { \
 		grpref = csch_grp_ref_get_top(sheet, obj); \
 		idx = -1; \
@@ -184,14 +184,14 @@ csch_inline csch_child_xform_t *csch_grp_ref_child_get_cx(csch_cgrp_t *grpref, c
 	assert(cx != NULL);
 
 /* returns 1 if child is part of a group ref (directly or indirectly)  */
-csch_inline int csch_obj_is_grp_ref_child(csch_sheet_t *sheet, csch_chdr_t *obj)
+RND_INLINE int csch_obj_is_grp_ref_child(csch_sheet_t *sheet, csch_chdr_t *obj)
 {
 	CSCH_PREPARE_GRPREF;
 	return grpref != NULL;
 }
 
 /* returns 0 if obj is not affected and normal move should be performed */
-csch_inline int csch_grp_ref_child_moved(csch_sheet_t *sheet, csch_chdr_t *obj, csch_coord_t dx, csch_coord_t dy, int undoable)
+RND_INLINE int csch_grp_ref_child_moved(csch_sheet_t *sheet, csch_chdr_t *obj, csch_coord_t dx, csch_coord_t dy, int undoable)
 {
 	int zero = 0;
 	CSCH_PREPARE_GRPREF;
@@ -205,7 +205,7 @@ csch_inline int csch_grp_ref_child_moved(csch_sheet_t *sheet, csch_chdr_t *obj,
 }
 
 /* returns 0 if obj is not affected and normal move should be performed */
-csch_inline int csch_grp_ref_child_rotated(csch_sheet_t *sheet, csch_chdr_t *obj, csch_coord_t rcx, csch_coord_t rcy, double da, int undoable)
+RND_INLINE int csch_grp_ref_child_rotated(csch_sheet_t *sheet, csch_chdr_t *obj, csch_coord_t rcx, csch_coord_t rcy, double da, int undoable)
 {
 	int zero = 0;
 	csch_coord_t x, y;
@@ -227,7 +227,7 @@ csch_inline int csch_grp_ref_child_rotated(csch_sheet_t *sheet, csch_chdr_t *obj
 }
 
 /* returns 0 if obj is not affected and normal move should be performed */
-csch_inline int csch_grp_ref_child_rotated90(csch_sheet_t *sheet, csch_chdr_t *obj, csch_coord_t rcx, csch_coord_t rcy, int steps, int undoable)
+RND_INLINE int csch_grp_ref_child_rotated90(csch_sheet_t *sheet, csch_chdr_t *obj, csch_coord_t rcx, csch_coord_t rcy, int steps, int undoable)
 {
 	int zero = 0;
 	csch_coord_t x, y;
@@ -248,7 +248,7 @@ csch_inline int csch_grp_ref_child_rotated90(csch_sheet_t *sheet, csch_chdr_t *o
 }
 
 /* returns 0 if obj is not affected and normal move should be performed */
-csch_inline int csch_grp_ref_child_mirrored(csch_sheet_t *sheet, csch_chdr_t *obj, csch_coord_t mcx, csch_coord_t mcy, int mirx, int miry, int undoable)
+RND_INLINE int csch_grp_ref_child_mirrored(csch_sheet_t *sheet, csch_chdr_t *obj, csch_coord_t mcx, csch_coord_t mcy, int mirx, int miry, int undoable)
 {
 	int zero = 0;
 	csch_coord_t x, y;
