@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  cschem - modular/flexible schematics editor - libcschem (core library)
- *  Copyright (C) 2018, 2022 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2018, 2022, 2024 Tibor 'Igor2' Palinkas
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -197,7 +197,8 @@ typedef enum csch_sheet_type_e {
 	CSCH_SHTY_unknown,
 	CSCH_SHTY_UNLISTED, /* not explicitly listen in the project file, just happens to be in the same dir */
 	CSCH_SHTY_ROOT,     /* explicitly listed in project file as a root sheet */
-	CSCH_SHTY_AUX       /* explicitly listed in project file as an aux sheet */
+	CSCH_SHTY_AUX,      /* explicitly listed in project file as an aux sheet */
+	CSCH_SHTY_EXTERNAL  /* not explicitly listen in the project file, loaded during compilation, for hierarchy */
 } csch_sheet_type_t;
 
 struct csch_sheet_s {
