@@ -31,6 +31,7 @@
 #include <puplug/error.h>
 #include <librnd/core/unit.h>
 #include <librnd/core/misc_util.h>
+#include <librnd/core/compat_misc.h>
 
 #include "libcschem.h"
 #include "buildin.h"
@@ -53,10 +54,11 @@ minuid_session_t csch_minuid;
 
 int csch_init(void)
 {
+	int pid = rnd_getpid();
+
 	minuid_init(&csch_minuid);
-#ifdef __WIN32__
-#error need to get some good random source
-#endif
+	minuid_salt(&csch_minuid, &pid, sizeof(pid));
+
 	csch_plug_library_init();
 	return 0;
 }
