@@ -33,8 +33,8 @@
 #include "cnc_obj.h"
 #include "cnc_any_obj.h"
 #include "plug_io.h"
-#include "util_path.h"
 #include <librnd/core/compat_misc.h>
+#include <librnd/core/compat_fs.h>
 #include "project.h"
 #include "integrity.h"
 #include <librnd/core/safe_fs.h>
@@ -490,12 +490,15 @@ typedef enum { SS_SAVE_SHEET, SS_SAVE_SHEET_BACKUP, SS_EXPORT_SHEET, SS_SAVE_BUF
 static int csch_export_or_save_sheet(csch_sheet_t *sheet, const char *fn_, const char *fmt, save_sheet_t stype, int preserve_changed)
 {
 	vtpr_t prios;
-	int n, ret = -1, len;
+	int n, ret = -1, len, preserve_name = 0;
 	char *fn, *ext = NULL;
 
 	if ((fmt == NULL) || (*fmt == '\0'))
 		return -1;
 
+	if (stype == SS_SAVE_SHEET_BACKUP)
+		preserve_name = 1;
+
 	if (sheet->is_symbol && ((stype == SS_SAVE_SHEET) || (stype == SS_SAVE_SHEET_BACKUP)))
 		stype = SS_SAVE_SHEET_AS_SYM;
 
@@ -555,13 +558,18 @@ static int csch_export_or_save_sheet(csch_sheet_t *sheet, const char *fn_, const
 				else
 					ret = pr->io->save_sheet(fn, fmt, sheet);
 
-				if ((stype == SS_SAVE_SHEET) || (stype == SS_SAVE_SHEET_AS_SYM)) {
+				if (!preserve_name && ((stype == SS_SAVE_SHEET) || (stype == SS_SAVE_SHEET_AS_SYM))) {
 					char *newname = rnd_lrealpath(fn);
+					if (newname == NULL) {
+						rnd_message(RND_MSG_ERROR, "Failed to realpath(%s)\nMight be write permission problems\n", fn);
+						ret = -1;
+						goto error;
+					}
 					if ((sheet->hidlib.fullpath == NULL) || (strcmp(sheet->hidlib.fullpath, newname) != 0)) {
 						free(sheet->hidlib.fullpath);
 						sheet->hidlib.fullpath = newname;
 						free(sheet->hidlib.loadname);
-						sheet->hidlib.loadname = rnd_strdup(csch_basename(newname));
+						sheet->hidlib.loadname = rnd_strdup(rnd_basename(newname));
 					}
 					else
 						free(newname);
@@ -583,6 +591,7 @@ static int csch_export_or_save_sheet(csch_sheet_t *sheet, const char *fn_, const
 			break;
 	}
 
+	error:;
 	free(fn);
 	vtpr_uninit(&prios);
 	return ret;
