@@ -50,7 +50,7 @@ struct csch_lib_backend_s {
 	const char *name;
 
 	/* called with a path to a resource; returns root or realpath(3) of root if applicable */
-	char *(*realpath)(rnd_design_t *hl, char *root);
+	char *(*realpath)(rnd_design_t *hl, const char *root);
 
 	/* called with a path to a resource; map and build the slib tree under
 	   root_dir. Return 0 on success. Do not add anything to the tree on error.
@@ -97,6 +97,7 @@ struct csch_lib_s {
 
 	const char *error;   /* if not NULL, there was an error accessing this node */
 	unsigned int hide:1; /* hide from the UI */
+	unsigned just_mapped:1;   /* in root: set right after mapping/scanning a root from disk */
 
 	csch_lib_t *parent; /* NULL in the first level of root dirs */
 	vtp0_t children;
@@ -119,8 +120,10 @@ typedef struct csch_lib_master_s {
 
 /*** calls for lib users ***/
 
-/* call csch_lib_add() for all configured lib paths in sheet */
-void csch_lib_add_all(csch_sheet_t *sheet, csch_lib_master_t *master, const rnd_conflist_t *searchpath);
+/* call csch_lib_add() for all configured lib paths in sheet; re-scan
+   existing libs only if do_rehash is non-zero; new libraries found
+   that were not present previously are always scanned */
+void csch_lib_add_all(csch_sheet_t *sheet, csch_lib_master_t *master, const rnd_conflist_t *searchpath, int do_rehash);
 
 /* Re-map the root of an existing node */
 int csch_lib_rehash(csch_sheet_t *sheet, csch_lib_master_t *master, csch_lib_t *node);
@@ -153,7 +156,12 @@ csch_lib_t *csch_lib_alloc_append(const csch_lib_backend_t *be, csch_lib_t *pare
 void csch_lib_backend_reg(csch_lib_master_t *master, const csch_lib_backend_t *be);
 
 /*** calls for internal use ***/
-int csch_lib_add(csch_sheet_t *sheet, csch_lib_master_t *master, char *path, int append);
+/* Rehash (re-scan) existing libraries only if do_rehash is non-zero; new
+   libraries just added are always scanned. skip_just_mapped is used by
+   csch_lib_add_all() to avoid redundant mapping. path needs to be strdup'd by
+   the caller, csch_lib_add() will take ownership of it. */
+int csch_lib_add(csch_sheet_t *sheet, csch_lib_master_t *master, char *path, int append, int do_rehash, int skip_just_mapped);
+
 int csch_lib_add_local(csch_sheet_t *sheet, csch_lib_master_t *master);
 void csch_lib_free(csch_lib_t *slib); /* doesn't remove from parent! */
 void csch_plug_symlib_init(void);
