@@ -71,8 +71,27 @@ fgw_error_t csch_act_CompileProject(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 }
 
 
+static const char csch_acts_DiscardAbstract[] = "CompileProject()";
+static const char csch_acth_DiscardAbstract[] = "Free the abstract model of the current project.";
+fgw_error_t csch_act_DiscardAbstract(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+{
+	rnd_design_t *hidlib = RND_ACT_DESIGN;
+	csch_sheet_t *sheet = (csch_sheet_t *)hidlib;
+	csch_project_t *prj = (csch_project_t *)sheet->hidlib.project;
+
+	if (prj->abst != NULL) {
+		csch_abstract_uninit(prj->abst);
+		free(prj->abst);
+		prj->abst = NULL;
+	}
+
+	RND_ACT_IRES(0);
+	return 0;
+}
+
 static rnd_action_t csch_project_act_list[] = {
 	{"CompileProject", csch_act_CompileProject, csch_acth_CompileProject, csch_acts_CompileProject},
+	{"DiscardAbstract", csch_act_DiscardAbstract, csch_acth_DiscardAbstract, csch_acts_DiscardAbstract}
 };
 
 void csch_project_act_init(void)
