@@ -10,7 +10,7 @@
    If require_conn is non-zero, throw an error message when there is no
    graphical connection on the port (useful for gnd/vcc/rail symbols).
 */
-int csch_cmp_nameconn_port_net(csch_acomp_t *comp, const char *portname, const char *netname, int require_conn);
+int csch_cmp_nameconn_port_net(csch_project_t *prj, csch_acomp_t *comp, const char *portname, const char *netname, int require_conn, int view_id, csch_hier_path_t *hpath);
 
 /* Merge n1 and n2, keeping one of them, making the other empty; return the
    one kept. (Tries to keep the one with name) */
