@@ -233,6 +233,13 @@ static void grp_pen_rename(csch_sheet_t *sheet, csch_cgrp_t *grp, const char *re
 				csch_chdr_pen_name_modify(sheet, obj, &stroke_name, NULL, 1);
 			}
 		}
+		if ((obj->fill_name.str != NULL) && re_sei_exec(rx, obj->fill_name.str)) {
+			char *dst;
+			if (re_sei_subst(rx, &dst, obj->fill_name.str, subst, 0)) {
+				csch_comm_str_t fill_name = csch_comm_str(sheet, dst, 1);
+				csch_chdr_pen_name_modify(sheet, obj, NULL, &fill_name, 1);
+			}
+		}
 	}
 
 	re_sei_free(rx);
