@@ -40,16 +40,17 @@
 #include "util_lib_fs.h"
 
 
-char *csch_lib_fs_realpath(rnd_design_t *hl, char *root)
+char *csch_lib_fs_realpath(rnd_design_t *hl, const char *root)
 {
-	char *path = root, *rp;
+	char *patha, *rp;
+	const char *path = root;
 
 	if (*path == '?')
 		path++;
 
-	path = rnd_build_fn(hl, path);
-	rp = rnd_lrealpath(path);
-	free(path);
+	patha = rnd_build_fn(hl, path);
+	rp = rnd_lrealpath(patha);
+	free(patha);
 	return rp;
 }
 
