@@ -971,7 +971,7 @@ void csch_wirenet_recalc_junctions(csch_sheet_t *sheet, csch_cgrp_t *wirenet)
 		   create new wirenets for each segment and move objects into them */
 		if (!wirenet->wirenet_split_lock && (map.seg_next > 2)) {
 			htpi_entry_t *e;
-			csch_cgrp_t **new_seg = calloc(sizeof(csch_cgrp_t), map.seg_next);
+			csch_cgrp_t **new_seg = calloc(sizeof(csch_cgrp_t *), map.seg_next);
 
 			/* seg 0 is not used by the mapper; seg 1 is the segment we keep as original; from 2 up are the new segments (allocated on request) */
 			for(e = htpi_first(&map.obj2seg); e != NULL; e = htpi_next(&map.obj2seg, e)) {
