@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  sch-rnd - modular/flexible schematics editor - svg export
- *  Copyright (C) 2022 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2022, 2024 Tibor 'Igor2' Palinkas
  *
  *  (Supported by NLnet NGI0 PET Fund in 2022)
  *
@@ -63,6 +63,13 @@ const char *svg_cookie = "export_svg";
 
 static rnd_svg_t pctx_, *pctx = &pctx_;
 
+static const char *colorspace_names[] = {
+	"color",
+	"grayscale",
+	"monochrome",
+	NULL
+};
+
 static const rnd_export_opt_t svg_attribute_list[] = {
 	{"outfile", "Graphics output file",
 	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0},
@@ -87,6 +94,10 @@ static const rnd_export_opt_t svg_attribute_list[] = {
 	{"view", "If not empty, switch to view and compile before exporting",
 	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0},
 #define HA_view 5
+
+	{"colorspace", "Export in color or reduce colorspace",
+	 RND_HATT_ENUM, 0, 0, {0, 0, 0}, colorspace_names}
+#define HA_colorspace 6
 };
 
 #define NUM_OPTIONS (sizeof(svg_attribute_list)/sizeof(svg_attribute_list[0]))
@@ -147,6 +158,8 @@ static int svg_do_export_sheet(rnd_hid_t *hid, rnd_design_t *dsg, rnd_hid_attr_v
 	if (f != NULL)
 		rnd_svg_header(pctx);
 
+	pctx->colorspace = options[HA_colorspace].lng;
+
 	sch_rnd_set_export_layers(&xform, options[HA_layers].str);
 	svg_hid_export_to_file(dsg, pctx->outf, options, &xform);
 
