@@ -150,6 +150,7 @@ static void tdx_export_nets(FILE *f, csch_abstract_t *abs)
 	for(e = htsp_first(&abs->nets); e != NULL; e = htsp_next(&abs->nets, e)) {
 		csch_anet_t *net = e->value;
 		const char *netname = sch_nle_get_netname(net);
+		int net_exported = 0;
 
 		if (net->hdr.omit) continue;
 
@@ -195,6 +196,7 @@ static void tdx_export_nets(FILE *f, csch_abstract_t *abs)
 					*next = '\0';
 					next++;
 				}
+				net_exported = 1;
 				fprintf(f, "conn ");
 				tdx_fprint_escape(f, netname);
 				fputc(' ', f);
@@ -204,7 +206,8 @@ static void tdx_export_nets(FILE *f, csch_abstract_t *abs)
 				fputc('\n', f);
 			}
 		}
-		export_custom_attrs(f, netname, &net->hdr, "nettag");
+		if (net_exported) /* if there's no connection the net is unknown and shouldn't have tags either */
+			export_custom_attrs(f, netname, &net->hdr, "nettag");
 	}
 	gds_uninit(&tmp);
 }
