@@ -1,7 +1,7 @@
 /*
  *                            COPYRIGHT
  *
- *  cschem - modular/flexible schematics editor - GUI
+ *  sch-rnd - modular/flexible schematics editor - GUI
  *  Copyright (C) 2020,2022 Tibor 'Igor2' Palinkas
  *  (copied from camv-rnd by the author)
  *
@@ -431,10 +431,6 @@ static fgw_error_t csch_act_Save(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	return 0;
 }
 
-extern const char rnd_acts_Zoom_default[];
-extern fgw_error_t rnd_gui_act_zoom(fgw_arg_t *res, int argc, fgw_arg_t *argv);
-static const char csch_acth_Zoom[] = "GUI zoom";
-
 static const char csch_acts_SwitchRelative[] = "SwitchRelative(steps)\n";
 static const char csch_acth_SwitchRelative[] = "Switch to a different sheet by traversing integer steps on the linked list of sheets loaded";
 static fgw_error_t csch_act_SwitchRelative(fgw_arg_t *res, int argc, fgw_arg_t *argv)
@@ -465,8 +461,8 @@ static rnd_action_t sch_rnd_gui_action_list[] = {
 	{"Load", csch_act_Load, csch_acth_Load, csch_acts_Load},
 	{"Save", csch_act_Save, csch_acth_Save, csch_acts_Save},
 	{"SaveAs", csch_act_Save, csch_acth_SaveAs, csch_acts_SaveAs},
-	{"Zoom", rnd_gui_act_zoom, csch_acth_Zoom, rnd_acts_Zoom_default},
-	{"ZoomTo", rnd_gui_act_zoom, csch_acth_Zoom, rnd_acts_Zoom_default},
+	{"Zoom", csch_act_Zoom, csch_acth_Zoom, csch_acts_Zoom_},
+	{"ZoomTo", csch_act_Zoom, csch_acth_Zoom, csch_acts_Zoom_},
 	{"SwitchRelative", csch_act_SwitchRelative, csch_acth_SwitchRelative, csch_acts_SwitchRelative},
 	EDIT_ACTS
 	{"Popup", csch_act_Popup, csch_acth_Popup, csch_acts_Popup},
