@@ -934,11 +934,38 @@ static void parse_sch_strs(gdom_node_t *sch)
 	parse_sch_shape_canvas(data_str);
 }
 
-long easyeda_str2name(const char *str)
+/* Returns 1 if an unresolved node name in easyeda_gdom_str2name() is okay:
+   some subtrees will have custom node names (e.g. attribute key=val pairs) */
+RND_INLINE int easyeda_gdom_subtree_has_custom_keys(gdom_node_t *parent)
+{
+	if (parent == NULL)
+		return 0;
+
+	switch(parent->name) {
+		case easy_components:
+			return 1;
+	}
+
+	if ((parent->parent == NULL) || (parent->parent->parent == NULL))
+		return 0;
+
+	switch(parent->parent->parent->name) {
+		case easy_BOM:
+			return 1;
+	}
+
+	return 0;
+}
+
+/* uctx is ignored and parent may be NULL */
+long easyeda_gdom_str2name(void *uctx, gdom_node_t *parent, const char *str)
 {
 	long res = easy_sphash(str);
-	if (res < 0)
+	if (res < 0) {
+		if (easyeda_gdom_subtree_has_custom_keys(parent))
+			return GDOM_CUSTOM_NAME;
 		rnd_message(RND_MSG_ERROR, "Internal error: missing easyeda keyword '%s'\n", str);
+	}
 	return res;
 }
 
@@ -947,7 +974,7 @@ gdom_node_t *easystd_low_sch_parse(FILE *f, int is_sym)
 	gdom_node_t *root, *schs;
 
 	/* low level json parse -> initial dom */
-	root = gdom_json_parse(f, easyeda_str2name);
+	root = gdom_json_parse(f, easyeda_gdom_str2name);
 	if (root == NULL)
 		return NULL;
 
