@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  sch-rnd - modular/flexible schematics editor - gEDA file format support
- *  Copyright (C) 2022, 2023 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2022..2024 Tibor 'Igor2' Palinkas
  *
  *  (Supported by NLnet NGI0 PET Fund in 2022, Entrust in 2023)
  *
@@ -328,6 +328,27 @@ static csch_source_arg_t *geda_src(read_ctx_t *ctx)
 	return csch_attrib_src_c(ctx->fn, ctx->lineno, 0, NULL);
 }
 
+/* Create a scalar attribute key=val or if key already exist in obj->attr,
+   convert obj->attr into an arrayand append val */
+static void attr_set_maybe_arr(csch_sheet_t *sheet, csch_cgrp_t *obj, int prio, const char *key, const char *val, csch_source_arg_t *source)
+{
+	csch_attrib_t *a = csch_attrib_get(&obj->attr, key);
+
+	if (a == NULL) {
+		/* first value -> create attrs */
+		csch_cobj_attrib_set(sheet, obj, prio, key, val, source);
+		return;
+	}
+
+	/* in case we had a scalar value turn it into an array */
+	if (a->val != NULL) {
+		vts0_append(&a->arr, a->val);
+		a->val = NULL;
+	}
+
+	csch_attrib_append(&obj->attr, prio, key, val, source);
+}
+
 /* Create a text object and create attribue as needed. read_line returns an
    allocated string that will be free()'d here. Returns 0 on success. */
 static int place_text(read_ctx_t *ctx, csch_cgrp_t *parent, long x, long y, long nlines, const char *penname, int vis, int nvis, int rot, int align, int is_attr, int create_attr, char *(*read_line)(void *uctx), void *uctx)
@@ -359,7 +380,7 @@ static int place_text(read_ctx_t *ctx, csch_cgrp_t *parent, long x, long y, long
 			*sep = '\0';
 			sep++;
 			if (create_attr)
-				csch_cobj_attrib_set(ctx->sheet, parent, CSCH_ATP_USER_DEFAULT, s, sep, geda_src(ctx));
+				attr_set_maybe_arr(ctx->sheet, parent, CSCH_ATP_USER_DEFAULT, s, sep, geda_src(ctx));
 			if (vis) {
 				text = (csch_text_t *)csch_alien_mktext(&ctx->alien, parent, x, y, penname);
 				y -= DEF_TERM_GRID;
