@@ -895,10 +895,10 @@ static int parse_group_(read_ctx_t *ctx, csch_cgrp_t *grp, lht_node_t *subtree)
 	if (subtree == NULL)
 		return -1;
 
-	if (parse_uuid(ctx, &grp->uuid, lht_dom_hash_get(subtree, "uuid")) != 0)
+	if (parse_uuid(ctx, (unsigned char *)&grp->uuid, lht_dom_hash_get(subtree, "uuid")) != 0)
 		return -1;
 	if (grp->hdr.type == CSCH_CTYPE_GRP) {
-		if (parse_uuid(ctx, &grp->data.grp.src_uuid, lht_dom_hash_get(subtree, "src_uuid")) != 0)
+		if (parse_uuid(ctx, (unsigned char *)&grp->data.grp.src_uuid, lht_dom_hash_get(subtree, "src_uuid")) != 0)
 			return -1;
 	}
 
