@@ -1,7 +1,7 @@
 /*
  *                            COPYRIGHT
  *
- *  cschem - modular/flexible schematics editor - tEDAx non-graphical sheet support
+ *  sch-rnd - modular/flexible schematics editor - tEDAx non-graphical sheet support
  *  Copyright (C) 2023 Tibor 'Igor2' Palinkas
  *
  *  (Supported by NLnet NGI0 Entrust in 2023)
@@ -57,9 +57,9 @@ static char *ngrp_tedax_draw_getline(csch_sheet_t *sheet, long *cnt, void **cook
 	return sch_ngrp_draw_getline(sheet->non_graphical_data, cnt, cookie);
 }
 
-static int ngrp_tedax_compile_sheet(csch_abstract_t *dst, int viewid, const csch_sheet_t *src)
+static int ngrp_tedax_compile_sheet(csch_abstract_t *dst, int viewid, csch_hier_path_t *hpath, const csch_sheet_t *src)
 {
-	return sch_ngrp_compile_sheet(dst, viewid, src, src->non_graphical_data);
+	return sch_ngrp_compile_sheet(dst, viewid, hpath, src, src->non_graphical_data);
 }
 
 static int io_ngrp_tedax_parse_acompact_attrs(sch_ngrp_t *ctx, sch_ngrp_comp_t *dst, int argc, char *argv[], long lineno)
