@@ -1,7 +1,7 @@
 /*
  *                            COPYRIGHT
  *
- *  cschem - modular/flexible schematics editor - GUI
+ *  sch-rnd - modular/flexible schematics editor - standard cschem forge
  *  Copyright (C) 2023 Tibor 'Igor2' Palinkas
  *
  *  (Supported by NLnet NGI0 Entrust in 2023)
@@ -51,7 +51,9 @@
 #include <libcschem/search.h>
 
 /* This doesn't make a plugin dep as only inlines and macros and structs are used */
-#include <plugins/sch_dialogs/timed_chg.h>
+#include <sch-rnd/conf_core.h>
+#define RND_TIMED_CHG_TIMEOUT conf_core.editor.edit_time
+#include <librnd/plugins/lib_hid_common/timed_chg.h>
 
 #include <sch-rnd/conf_core.h>
 #include <sch-rnd/crosshair.h>
@@ -82,7 +84,7 @@ typedef struct test_bench_dlg_ctx_s {
 
 	/* timed update */
 	unsigned inhibit_pend:1; /* don't start the timer on the same dialog for our own mods */
-	csch_timed_chg_t pend;
+	rnd_timed_chg_t pend;
 
 	gdl_elem_t link;
 	test_bench_row_t row[1]; /* over-allocated for num_benches */
@@ -129,7 +131,7 @@ static void test_bench_free(test_bench_dlg_ctx_t *ctx)
 {
 	long n;
 
-	csch_timed_chg_cancel(&ctx->pend);
+	rnd_timed_chg_cancel(&ctx->pend);
 
 	if (ctx->modal)
 		return; /* will be free'd once at the end, after run() */
@@ -329,7 +331,7 @@ static int sch_rnd_test_bench_dlg(const vtp0_t *objs, int modal)
 	ctx->num_benches = numb;
 	ctx->num_objs = numo;
 	ctx->obj = malloc(sizeof(test_bench_obj_t *) * ctx->num_objs);
-	csch_timed_chg_init(&ctx->pend, timed_update_cb, ctx);
+	rnd_timed_chg_init(&ctx->pend, timed_update_cb, ctx);
 
 	gdl_append(&test_bench_dlgs, ctx, link);
 
@@ -622,7 +624,7 @@ static void test_bench_onchg(rnd_design_t *hidlib, void *user_data, int argc, rn
 	test_bench_dlg_ctx_t *ctx;
 	for(ctx = gdl_first(&test_bench_dlgs); ctx != NULL; ctx = gdl_next(&test_bench_dlgs, ctx))
 		if (!ctx->inhibit_pend && sheet_in_dlg(ctx, hidlib))
-			csch_timed_chg_schedule(&ctx->pend);
+			rnd_timed_chg_schedule(&ctx->pend);
 }
 
 static rnd_conf_hid_id_t test_bench_hid_id;
