@@ -209,6 +209,12 @@ static void line_create_all(rnd_design_t *hl, csch_cgrp_t *parent, int wirenet)
 				continue;
 			if (!wirenet) {
 				csch_line_t *line = (csch_line_t *)csch_op_create(sheet, parent, CSCH_CTYPE_LINE);
+
+				if (line == NULL) {
+					rnd_message(RND_MSG_ERROR, "Failed to create line object\n");
+					return;
+				}
+
 				line->spec.p1.x = x1; line->spec.p1.y = y1;
 				line->spec.p2.x = x2; line->spec.p2.y = y2;
 
