@@ -404,7 +404,7 @@ fgw_error_t target_spice_compile_component1(fgw_arg_t *res, int argc, fgw_arg_t
 	if (portmap != NULL) {
 		/* rnd_trace("spice pm: %s\n", comp->name);*/
 		src = csch_attrib_src_p("target_spice", "acquired from spice/portmap");
-		csch_compile_attribute(&comp->hdr, "portmap", portmap, src, "component", comp->name, 0, 1, NULL);
+		csch_compile_attribute(&comp->hdr, "portmap", portmap, src, "component", comp->name, NULL, 0, 1, NULL);
 	}
 
 
