@@ -235,6 +235,11 @@ fgw_error_t csch_act_New(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	if (fn == NULL) /* cancel */
 		return 0;
 
+	if (strpbrk(fn, "/\\") != NULL) {
+		rnd_message(RND_MSG_ERROR, "New(): sheet name can not contain path separator (use basename, not path)\n");
+		return FGW_ERR_ARG_CONV;
+	}
+
 	path = rnd_concat(dn, "/", fn, NULL);
 	if (rnd_file_readable(RND_ACT_DESIGN, path)) {
 		int go_for_it;
