@@ -220,7 +220,7 @@ static rnd_font_t *rf_font_lookup(rnd_design_t *hidlib, const char *name, const
 			embf = malloc(sizeof(rnd_font_t));
 			rnd_font_load_internal(embf, embf_font, sizeof(embf_font) / sizeof(embf_font[0]), embf_minx, embf_miny, embf_maxx, embf_maxy);
 			embf_parsed = 1;
-			htsp_set(&rf_map, emb_font_key, embf);
+			htsp_set(&rf_map, (char *)emb_font_key, embf); /* there's an extra if() for not freeing this */
 		}
 		res = embf;
 	}
