@@ -29,4 +29,6 @@ action_entry(Sym)
 action_entry(Symbol)
 action_entry(Term)
 action_entry(Terminal)
+action_entry(TextHeight)
+action_entry(TextWidth)
 action_entry(Vertical)
