@@ -104,11 +104,20 @@ static int sch_rnd_human_coord(rnd_coord_t coord, double *out_val, const char **
 	return 1;
 }
 
+#ifdef RND_WANT_FLOATING_FHS
+	char *sch_floating_confdir;
+#endif
+
 static char *main_path_init(char *exec_prefix)
 {
 	char *tmp;
 	int se = 0;
 
+#ifdef RND_WANT_FLOATING_FHS
+	TODO("This ignores ./configure --confdir; the code is in librnd trunk/src/librnd/scconfig/hooks_common.h, search for ''set up confdir'' -> should save a variant usable here, without prefix");
+	sch_floating_confdir = rnd_concat(rnd_w32_root, "/etc/sch-rnd", NULL);
+#endif
+
 	/* export the most important paths and data for child processes (e.g. parametric footprints) */
 	tmp = rnd_concat(SCHSHAREDIR, "/footprint", NULL);
 	se |= rnd_setenv("SCH_RND_VERSION",     SCH_VERSION,           1);
@@ -131,8 +140,14 @@ static char *main_path_init(char *exec_prefix)
 
 	rnd_conf_postproc(); /* get ~ (home dir) set */
 
-	rnd_app.conf_sysdir_path = SCHSHAREDIR;
+
+#ifdef RND_WANT_FLOATING_FHS
+	rnd_app.conf_sys_path = rnd_concat(SCHCONFDIR, "/sch-rnd-conf.lht", NULL);
+#else
 	rnd_app.conf_sys_path = SCHCONFDIR "/sch-rnd-conf.lht";
+#endif
+
+	rnd_app.conf_sysdir_path = SCHSHAREDIR;
 	rnd_app.lib_dir = SCHLIBDIR;
 	rnd_app.conf_userdir_path = CONF_USER_DIR;
 	rnd_app.conf_user_path = rnd_concat(CONF_USER_DIR, "/conf_core.lht", NULL);
